"""
1.0.1新增level引數
1.0.2給level預設值,使模組支援二種api(level可填可不填)
"""
def printNext(theList,level=0):
    for eachN in theList:
        if isinstance(eachN,list):
            printNext(eachN,level+1)
        else:
            for tabStop in range(level):
                print("\t",end='')      #end=''不換行
            print(eachN)



from distutils.core import setup
setup(
        name        ='yhwNester',
        version     ='1.0.2',
        py_modules  =['yhwNester'],        #將模組的中介資料關聯到setup函式的引數
        author      ='yhw',
        author_email='yuhung.tw@icloud.com',
        url         ='http://www.yuhung.tw',
        description ='A sample module',
     )
